@@ -2,7 +2,7 @@ package Test2::Formatter::Test2;
 use strict;
 use warnings;
 
-our $VERSION = '0.001017';
+our $VERSION = '0.001018';
 
 use Scalar::Util qw/blessed/;
 use List::Util qw/shuffle first/;
@@ -641,7 +641,7 @@ sub render_errors {
     } @{$f->{errors}};
 }
 
-sub DESTORY {
+sub DESTROY {
     my $self = shift;
 
     my $io = $self->{+IO} or return;
