@@ -2,7 +2,7 @@ package Test2::Harness::Run::Runner::ProcMan::Scheduler::Finite;
 use strict;
 use warnings;
 
-our $VERSION = '0.001017';
+our $VERSION = '0.001018';
 
 use List::Util qw/sum/;
 
@@ -66,7 +66,7 @@ sub _fetch {
 
     # Long and Medium float to the top, but only if the slots are not all
     # saturated with them.
-    if ($max > ($total - 1)) {
+    if ($not_short < ($max - 1)) {
         return shift @{$queues->{+LNG}} if @{$queues->{+LNG}};
         return shift @{$queues->{+MED}} if @{$queues->{+MED}};
     }
